"use strict";
// FYI
// packages/@guardian/src-foundations/src/mq/mq.ts SYMLINKS TO
// packages/@guardian/source-foundations/src/mq.ts
Object.defineProperty(exports, "__esModule", { value: true });
exports.between = exports.until = exports.from = void 0;
const breakpoints_1 = require("./breakpoints");
const minWidth = (from) => `@media (min-width: ${`${from}px`})`;
const maxWidth = (until) => `@media (max-width: ${`${until - 1}px`})`;
const minWidthMaxWidth = (from, until) => `@media (min-width: ${`${from}px`}) and (max-width: ${`${until - 1}px`})`;
// e.g. from.*
exports.from = {
    mobile: minWidth(breakpoints_1.breakpoints.mobile),
    mobileMedium: minWidth(breakpoints_1.breakpoints.mobileMedium),
    mobileLandscape: minWidth(breakpoints_1.breakpoints.mobileLandscape),
    phablet: minWidth(breakpoints_1.breakpoints.phablet),
    tablet: minWidth(breakpoints_1.breakpoints.tablet),
    desktop: minWidth(breakpoints_1.breakpoints.desktop),
    leftCol: minWidth(breakpoints_1.breakpoints.leftCol),
    wide: minWidth(breakpoints_1.breakpoints.wide),
};
// e.g. until.*
exports.until = {
    mobile: maxWidth(breakpoints_1.breakpoints.mobile),
    mobileMedium: maxWidth(breakpoints_1.breakpoints.mobileMedium),
    mobileLandscape: maxWidth(breakpoints_1.breakpoints.mobileLandscape),
    phablet: maxWidth(breakpoints_1.breakpoints.phablet),
    tablet: maxWidth(breakpoints_1.breakpoints.tablet),
    desktop: maxWidth(breakpoints_1.breakpoints.desktop),
    leftCol: maxWidth(breakpoints_1.breakpoints.leftCol),
    wide: maxWidth(breakpoints_1.breakpoints.wide),
};
// e.g. between.*.and.*
exports.between = {
    mobile: {
        and: {
            mobileMedium: minWidthMaxWidth(breakpoints_1.breakpoints.mobile, breakpoints_1.breakpoints.mobileMedium),
            mobileLandscape: minWidthMaxWidth(breakpoints_1.breakpoints.mobile, breakpoints_1.breakpoints.mobileLandscape),
            phablet: minWidthMaxWidth(breakpoints_1.breakpoints.mobile, breakpoints_1.breakpoints.phablet),
            tablet: minWidthMaxWidth(breakpoints_1.breakpoints.mobile, breakpoints_1.breakpoints.tablet),
            desktop: minWidthMaxWidth(breakpoints_1.breakpoints.mobile, breakpoints_1.breakpoints.desktop),
            leftCol: minWidthMaxWidth(breakpoints_1.breakpoints.mobile, breakpoints_1.breakpoints.leftCol),
            wide: minWidthMaxWidth(breakpoints_1.breakpoints.mobileMedium, breakpoints_1.breakpoints.wide),
        },
    },
    mobileMedium: {
        and: {
            mobileLandscape: minWidthMaxWidth(breakpoints_1.breakpoints.mobileMedium, breakpoints_1.breakpoints.mobileLandscape),
            phablet: minWidthMaxWidth(breakpoints_1.breakpoints.mobileMedium, breakpoints_1.breakpoints.phablet),
            tablet: minWidthMaxWidth(breakpoints_1.breakpoints.mobileMedium, breakpoints_1.breakpoints.tablet),
            desktop: minWidthMaxWidth(breakpoints_1.breakpoints.mobileMedium, breakpoints_1.breakpoints.desktop),
            leftCol: minWidthMaxWidth(breakpoints_1.breakpoints.mobileMedium, breakpoints_1.breakpoints.leftCol),
            wide: minWidthMaxWidth(breakpoints_1.breakpoints.mobileMedium, breakpoints_1.breakpoints.wide),
        },
    },
    mobileLandscape: {
        and: {
            phablet: minWidthMaxWidth(breakpoints_1.breakpoints.mobileLandscape, breakpoints_1.breakpoints.phablet),
            tablet: minWidthMaxWidth(breakpoints_1.breakpoints.mobileLandscape, breakpoints_1.breakpoints.tablet),
            desktop: minWidthMaxWidth(breakpoints_1.breakpoints.mobileLandscape, breakpoints_1.breakpoints.desktop),
            leftCol: minWidthMaxWidth(breakpoints_1.breakpoints.mobileLandscape, breakpoints_1.breakpoints.leftCol),
            wide: minWidthMaxWidth(breakpoints_1.breakpoints.mobileLandscape, breakpoints_1.breakpoints.wide),
        },
    },
    phablet: {
        and: {
            tablet: minWidthMaxWidth(breakpoints_1.breakpoints.phablet, breakpoints_1.breakpoints.tablet),
            desktop: minWidthMaxWidth(breakpoints_1.breakpoints.phablet, breakpoints_1.breakpoints.desktop),
            leftCol: minWidthMaxWidth(breakpoints_1.breakpoints.phablet, breakpoints_1.breakpoints.leftCol),
            wide: minWidthMaxWidth(breakpoints_1.breakpoints.phablet, breakpoints_1.breakpoints.wide),
        },
    },
    tablet: {
        and: {
            desktop: minWidthMaxWidth(breakpoints_1.breakpoints.tablet, breakpoints_1.breakpoints.desktop),
            leftCol: minWidthMaxWidth(breakpoints_1.breakpoints.tablet, breakpoints_1.breakpoints.leftCol),
            wide: minWidthMaxWidth(breakpoints_1.breakpoints.tablet, breakpoints_1.breakpoints.wide),
        },
    },
    desktop: {
        and: {
            leftCol: minWidthMaxWidth(breakpoints_1.breakpoints.desktop, breakpoints_1.breakpoints.leftCol),
            wide: minWidthMaxWidth(breakpoints_1.breakpoints.desktop, breakpoints_1.breakpoints.wide),
        },
    },
    leftCol: {
        and: {
            wide: minWidthMaxWidth(breakpoints_1.breakpoints.leftCol, breakpoints_1.breakpoints.wide),
        },
    },
};
//# sourceMappingURL=mq.js.map